@@ -1,5 +1,5 @@
 /* This file is part of the Zebra server.
-   Copyright (C) 1994-2011 Index Data
+   Copyright (C) 2004-2013 Index Data
 
 Zebra is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -145,6 +145,9 @@ void tst(int argc, char **argv)
 
     zebra_close(zh);
 
+    /* testing indexing of bad UTF-8 encoded MARC record */
+    zh = index_some(zs, "dom.dom-config-utf8.xml", "bad-utf8.mrc");
+    zebra_close(zh);
 
     YAZ_CHECK(tl_close_down(0, zs));
 }
